#
# spec file for package pngquant
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pngquant
Version:        2.18.0
Release:        1.6
Summary:        Tool for lossy compression of PNG images
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://pngquant.org/
Source:         https://github.com/kornelski/pngquant/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(imagequant) >= %{version}
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(zlib)

%description
pngquant is a command-line utility and a library for lossy
compression of PNG images.

The conversion reduces file sizes by converting images to 1/2/4/8-bit
paletted PNG format with alpha channel (often 60-80%% smaller than
24/32-bit PNG files). Generated images are compatible with all modern
web browsers, and have better fallback in IE6 than 24-bit PNGs.

%prep
%setup -q

%build
# not autoconf
./configure \
	--prefix=%{_prefix} \
%ifarch x86_64
	--enable-sse \
%else
	--disable-sse \
%endif
	--extra-cflags='%{optflags}' \
	--with-libimagequant=%{_libdir} \
	--with-openmp
%make_build

%install
%make_install

%files
%license COPYRIGHT
%doc CHANGELOG README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun Jan 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.18.0:
  * build fixes on ARM
  * small quality improvement
* Sat Nov 27 2021 Dirk Müller <dmueller@suse.com>
- update to 2.17.0:
  - reduced stack usage, preventing stack overflow in pathological cases
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 2.15.0:
  - speed and quality improvements
* Wed Dec 23 2020 Dirk Müller <dmueller@suse.com>
- update to 2.13.1:
  - small speed and quality improvements
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.12.6
  * Warn about GCC 4 being too old
  * Use size_t for malloc sizes
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Update description with parts
  from README.md.
* Mon Feb 11 2019 munix9@googlemail.com
- update to version 2.12.2
  * improved speed on large images
* Thu Mar 22 2018 jengelh@inai.de
- Abolish %%__ type macro indirections.
* Mon Mar 19 2018 schwab@suse.de
- Pass --disable-sse on non-x86_64 for reproducability
- Don't strip binaries
- Use %%doc
* Tue Jan 30 2018 bjorn.lie@gmail.com
- Drop %%%%ix86 conditional, only pass --enable-sse for x86_64.
* Thu Nov 16 2017 dimstar@opensuse.org
- Update to version 2.11.2:
  + added support for `-o -`.
  + windows/JNI build fixes.
- Changes from version 2.8:
  + libimagequant is a separate project.
  + --strip option to disable copying of PNG metadata.
- Changes from version 2.7:
  + improved dithering of saturated and semitransparent colors.
  + fixed order of log output when using openmp.
  + improved quality sanity check in --skip-if-larger option.
  + disabled palette post-processing on colors from --map option to
    preserve them exactly.
- Changes from version 2.6:
  + when source image has no color profile information, the output
    won't have either.
- Changes from version 2.5:
  + replaced color search algorithm with vantage point tree, which
    is much faster and more reliable.
  + deprecated IE6 workaround.
  + warn when compiled without color profile support.
  + Rust API for libimagequant.
- Changes from version 2.4:
  + fixed remapping of bright colors when dithering.
- BuildRequire libimagequant-devel: the library lives in a separate
  project since version 2.8.
* Sat Oct 25 2014 opensuse@dstoecker.de
- update to version 2.3.1
* Sat Aug  9 2014 joerg@afflerbach.info
- Update to version 2.3.0
* Sat Dec  1 2012 joerg@afflerbach.info
- Building with OpenMP support makes pngquant faster in wall-clock time on multicore machines when one image at a time is processed.
- Version 1.8.0
